@@ -129,7 +129,4 @@ class Collection:
             has_archive=True
             routes = [attrval]
 
-        sub = SubCollection()
-
-        print(sub.archive.pages)
-        return sub
+        return SubCollection()
